Cepton Python SDK
=================

## Installation

```sh
pip install cepton_sdk
```

To install extra dependencies

```sh
pip install cepton_sdk[capture,export,plot]
```

## Documentation

- `docs/html/index.html`
